# Changelog

## [0.3.0](https://github.com/ValueArchitectsAI/sop-mcp/compare/v0.2.0...v0.3.0) (2026-02-13)


### Features

* add E2E MCP tests over stdio and gitignore feedback.md ([58d7d6d](https://github.com/ValueArchitectsAI/sop-mcp/commit/58d7d6d113d5c8978cb876a8bea4f2320ddeedb7))
* Add PyPI badges, one-click install links, and fix CI workflows ([#6](https://github.com/ValueArchitectsAI/sop-mcp/issues/6)) ([bcd58fc](https://github.com/ValueArchitectsAI/sop-mcp/commit/bcd58fc89646600c67701e8e543c0675f46d0c3b))
* add SOP storage abstraction layer ([d402f49](https://github.com/ValueArchitectsAI/sop-mcp/commit/d402f49910e4b272f36c27475944b154ecd910d5))
* add time estimate warning on publish, update README and steering ([98946a8](https://github.com/ValueArchitectsAI/sop-mcp/commit/98946a88707fb2ff2fbd65b1ead5f68df0e57ea0))
* support Python 3.10-3.13, add tox-uv for multi-version testing ([c301643](https://github.com/ValueArchitectsAI/sop-mcp/commit/c301643a03bac6dcfcc51823d77c4b7840973022))


### Bug Fixes

* add contents:read permission to publish jobs ([362b835](https://github.com/ValueArchitectsAI/sop-mcp/commit/362b835659331082effa95cd03f5bef82ab574cb))
* cap hypothesis &lt;6.150 to fix Python 3.12 CI failure ([0b6109f](https://github.com/ValueArchitectsAI/sop-mcp/commit/0b6109f108e13e443f092cf7e84304b5edc4bd46))
* resolve ruff linting and formatting issues across src/ and tests/ ([315e30e](https://github.com/ValueArchitectsAI/sop-mcp/commit/315e30eae3f82108090847384e1f995543b0b54a))
* sort imports in test_storage_backend, add lint+test pre-commit hook ([0980da9](https://github.com/ValueArchitectsAI/sop-mcp/commit/0980da94c04c5cf9f53e5e999279ef686c3d75e8))
* use uv sync --frozen in CI to respect lockfile ([0ca6121](https://github.com/ValueArchitectsAI/sop-mcp/commit/0ca6121f83adc25b8843872c1050806937e58584))


### Documentation

* add AGENT.md, remove .kiro steering, untrack .vscode and .DS_Store ([4ee71a9](https://github.com/ValueArchitectsAI/sop-mcp/commit/4ee71a93437ddf85313d70171b1067de1ceefc60))

## [0.2.0](https://github.com/ValueArchitectsAI/sop-mcp/compare/v0.1.0...v0.2.0) (2026-02-13)


### Features

* Add PyPI badges, one-click install links, and fix CI workflows ([#6](https://github.com/ValueArchitectsAI/sop-mcp/issues/6)) ([bcd58fc](https://github.com/ValueArchitectsAI/sop-mcp/commit/bcd58fc89646600c67701e8e543c0675f46d0c3b))
